| Home | Libraries | People | FAQ | More

## History

##### 1.56.0

- Moved `<boost/cstdint.hpp>` into Boost.Config.

##### 1.42.0

- Reverted Trunk to release branch state (i.e. a "known good state").
- Fixed issues: 653, 3084, 3177, 3180, 3568, 3657, 2134.
- Added long long support to `boost::static_log2`, `boost::static_signed_min`, `boost::static_signed_max`, `boost::static_unsigned_min` `boost::static_unsigned_max`, when available.
- The argument type and the result type of `boost::static_signed_min` etc are now typedef'd. Formerly, they were hardcoded as `unsigned long` and `int` respectively. Please, use the provided typedefs in new code (and update old code as soon as possible).

##### 1.32.0

- The argument type and the result type of `boost::static_log2` are now typedef'd. Formerly, they were hardcoded as `unsigned long` and `int` respectively. Please, use the provided typedefs in new code (and update old code as soon as possible).